@@ -69,7 +69,8 @@ FILTER_FIELDS = R.compose(
         # Minimum set for debugging speed
         lambda _: {
             'contains': dict(),
-            'icontains': dict()
+            'icontains': dict(),
+            'in': dict(type_modifier=lambda typ: graphene.List(typ))
         },
         lambda _: {
             'year': dict(allowed_types=[graphene.Date, graphene.DateTime]),
@@ -613,11 +614,10 @@ def input_type_fields(fields_dict, crud, parent_type_classes=[]):
     )
 
 
-def key_value_based_on_unique_or_foreign(key_to_modified_key_and_value, fields_dict, all_present_keys, key):
+def key_value_based_on_unique_or_foreign(key_to_modified_key_and_value, fields_dict, key):
     """
         Returns either a simple dict(key=value) for keys that must have unique values (e.g. id, key, OneToOne rel)
         Returns dict(default=dict(key=value)) for keys that need not have unique values
-    :param {String} all_present_keys All keys specified for the insert or update
     :param {String} key: The key to test
     :return {dict}:
     """
@@ -646,32 +646,22 @@ def input_type_parameters_for_update_or_create(fields_dict, field_name_to_value)
     :return:
     """
 
+    # Convert foreign key dicts to their id, since Django expects the foreign key as an saved instance or id
+    _related_object_id_if_django_type = related_object_id_if_django_type(fields_dict)
+    key_to_modified_key_and_value = R.map_with_obj(
+        _related_object_id_if_django_type,
+        R.omit(['id'], field_name_to_value)
+    )
     if R.has('id', field_name_to_value):
         # If we are doing an update with an id then the only value that doesn't go in defaults is id
-        key_to_modified_key_and_value = R.map_key_values(
-            lambda key, value: [f'{key}_id', R.prop('id', value)] if
-            R.prop_or(False, 'django_type', fields_dict[key]) else
-            # No Change
-            [key, value],
-            R.omit(['id'], field_name_to_value)
-        )
         return dict(
             id=R.getitem('id', field_name_to_value),
-            defaults=key_to_modified_key_and_value
+            defaults=R.merge_all(R.values(key_to_modified_key_and_value))
         )
     else:
         # Otherwise if we are creating or might be updating because we match a unique group of fields
-        # TODO we really shouldn't allow updating without an id. Matching a unique group of fields without an id should be an error
-        # Convert foreign key dicts to their id, since Django expects the foreign key as an saved instance or id
-        # Example region = {id: 5} becomes region_id = 5
-        # This assumes id is the pk
-        key_to_modified_key_and_value = R.map_with_obj(
-            lambda key, value: {'%s_id' % key: R.prop('id', value)} if
-            R.prop_or(False, 'django_type', fields_dict[key]) else
-            # No Change
-            {key: value},
-            field_name_to_value
-        )
+        # TODO we really shouldn't allow updating without an id.
+        # Matching a unique group of fields without an id should be an error
         # Forms a dict(
         #   unique_key1=value, unique_key2=value, ...,
         #   defaults=(non_unique_key1=value, non_unique_key2=value, ...)
@@ -680,13 +670,35 @@ def input_type_parameters_for_update_or_create(fields_dict, field_name_to_value)
             lambda key, value: key_value_based_on_unique_or_foreign(
                 key_to_modified_key_and_value,
                 fields_dict,
-                R.keys(field_name_to_value),
                 key
             ),
             field_name_to_value
         ))
 
 
+@R.curry
+def related_object_id_if_django_type(fields_dict, key, value):
+    """
+        Determines if the key represents a property that is a djnago type and returns the id of the value if so
+        Convert foreign key dicts to their id, since Django expects the foreign key as an saved instance or id
+        Example region = {id: 5} becomes region_id = 5
+    :param fields_dict: Contains keys that might have a value with a 'django_type' property
+    :param key:  They current key
+    :param value:  They current value
+    :return:  {{key}_id, value.id} if the key represents a django type
+    """
+    try:
+        return {f'{key}_id': R.prop('id', value)} \
+            if R.prop_or(False, 'django_type', fields_dict[key]) \
+            else {key: value}
+
+    except Exception as e:
+        logging.error(
+            f'Problem with related types for key {key}, value {json.dumps(value)}'
+        )
+        raise e
+
+
 @R.curry
 def graphql_query(graphene_type, fields, query_name):
     """
